@@ -11,7 +11,11 @@ app.directive('notesTooltip', function () {
     return {
         restrict: 'A',
         link: function (scope, element) {
-            element.tooltip();
+            element.tooltip({'container': 'body'});
+
+            element.on('$destroy', function() {
+                element.tooltip('hide');
+            });
         }
     };
 });
