@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "الملاحظات",
     "New note" : "ملاحظة جديدة ",
-    "Note is currently saving. Leaving the page will delete all changes!" : "يتم حاليا حفظ الملاحظة. سيتم الغاء التعديلات عند الخروج من الصفحة",
+    "_%n word_::_%n words_" : ["كلمة","كلمة","كلمتان","كلمات","كلمات","كلمات"],
     "Delete note" : "حذف الملاحظة ",
     "Favorite" : "المفضلة ",
     "No notes found" : "لم يتم العثور على ملاحظات"
