@@ -4,6 +4,8 @@ OC.L10N.register(
     "Notes" : "Märkmed",
     "New note" : "Uus märge",
     "_%n word_::_%n words_" : ["%n sõna","%n sõna"],
-    "Delete note" : "Kustuta märge"
+    "Delete note" : "Kustuta märge",
+    "Favorite" : "Lemmik",
+    "No notes found" : "Märkmeid ei leitud"
 },
 "nplurals=2; plural=(n != 1);");
