@@ -4,6 +4,8 @@ OC.L10N.register(
     "Notes" : "یادداشت ها",
     "New note" : "یادداشت جدید",
     "_%n word_::_%n words_" : ["%n کلمه"],
-    "Delete note" : "حذف یادداشت"
+    "Delete note" : "حذف یادداشت",
+    "Favorite" : "برگزیده",
+    "No notes found" : "هیچ یادداشتی یافت نشد"
 },
 "nplurals=1; plural=0;");
