@@ -1,11 +1,10 @@
 OC.L10N.register(
     "notes",
     {
-    "Notes" : "Sporočilca",
-    "New note" : "Novo sporočilce",
-    "Note is currently saving. Leaving the page will delete all changes!" : "Sporočilce se še shranjuje. Če zapustite stran, bodo spremembe izgubljene!",
+    "Notes" : "Opombe",
+    "New note" : "Nove opombe",
     "_%n word_::_%n words_" : ["%n beseda","%n besedi","%n besede","%n besed"],
-    "Delete note" : "Izbriši sporočilce",
+    "Delete note" : "Pobriši opombe",
     "Favorite" : "Priljubljene",
     "No notes found" : "Ne najdem opomb"
 },
