@@ -4,6 +4,8 @@ OC.L10N.register(
     "Notes" : "Нотатки",
     "New note" : "Нова нотатка",
     "_%n word_::_%n words_" : ["%n слово","%n слів","%n слів"],
-    "Delete note" : "Вилучити нотатку"
+    "Delete note" : "Вилучити нотатку",
+    "Favorite" : "Улюблені",
+    "No notes found" : "Нотатки відсутні"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
